
# THIS FILE IS GENERATED FROM tyssue SETUP.PY
#
short_version = '0.7.0'
full_version = '0.7.0'
git_revision = '171544f8af2941e6bdb6a82cce117096ed0287ed'
release = True
if release:
    version = full_version
else:
    version = short_version
